@@ -102,7 +102,7 @@ use vars qw($VERSION $HANDLER_BASE_PACKAGE @PRODUCT_HANDLER_ORDERING);
 use Data::Dumper;
 use Module::Find;
 
-$VERSION = "0.65_1";
+$VERSION = "0.65_2";
 
 my $REGISTRY = {
                 # Agent based
@@ -285,7 +285,12 @@ Example:
   $val = $jmx->get_attribute("java.lang:type=Memory","HeapMemoryUsage");
   print Dumper($val);
 
-  
+  $VAR1 = {
+          'committed' => '174530560',
+          'used' => '35029320',
+          'max' => '1580007424',
+          'init' => '134217728'
+        };
 
 =item Single MBean, multiple attributes
 
@@ -296,11 +301,43 @@ fetched, otherwise unknown attributes are ignored.
   $val = $jmx->get_attribute("java.lang:type=Memory",["HeapMemoryUsage","NonHeapMemoryUsage"]);
   print Dumper($val);
 
+  $VAR1 = {
+          'NonHeapMemoryUsage' => {
+                                    'committed' => '87552000',
+                                    'used' => '50510976',
+                                    'max' => '218103808',
+                                    'init' => '24317952'
+                                  },
+          'HeapMemoryUsage' => {
+                                 'committed' => '174530560',
+                                 'used' => '37444832',
+                                 'max' => '1580007424',
+                                 'init' => '134217728'
+                               }
+        };
+
 =item MBean pattern, one or more attributes
 
   $val = $jmx->get_attribute("java.lang:type=*",["HeapMemoryUsage","NonHeapMemoryUsage"]);
   print Dumper($val);
 
+  $VAR1 = {
+          'java.lang:type=Memory' => {
+                                       'NonHeapMemoryUsage' => {
+                                                                 'committed' => '87552000',
+                                                                 'used' => '50514304',
+                                                                 'max' => '218103808',
+                                                                 'init' => '24317952'
+                                                               },
+                                       'HeapMemoryUsage' => {
+                                                              'committed' => '174530560',
+                                                              'used' => '38868584',
+                                                              'max' => '1580007424',
+                                                              'init' => '134217728'
+                                                            }
+                                     }
+        };
+
 The return value is a map with the matching MBean names as keys and as value
 another map, with attribute names keys and attribute value values. If not a
 singel MBean matches or not a single attribute can be found on the matching
